# TE923 {id=te923_notes}

Some station models will recognize up to 5 remote
temperature/humidity sensor units. Use the hardware switch
in each sensor unit to identify sensors. Use the
`sensor_map` in
`weewx.conf`
to associate each sensor with a database field. 

The station has either 208 or 3442 history records, depending on
the model. With an archive interval set to 5 minutes, that is just
over a day (208 records) or about 23 days (3442 records).

The TE923 driver will read history records from the station when
WeeWX starts up, but it does not support hardware record
generation.

## Configuring with `weectl device` {id=te923_configuration}

The TE923 can be configured with the utility
[`weectl device`](../utilities/weectl-device.md).

!!! Note
    Make sure you stop `weewxd` before running `weectl device`.


### `--help` {id=te923_help}

Invoking `weectl device` with the `--help` option

    weectl device /home/weewx/weewx.conf --help

will produce something like this:

```
Using configuration file /home/weewx/weewx.conf
Using TE923 driver version 0.21 (weewx.drivers.te923)
Usage: weectl device [config_file] [options] [--debug] [--help]

Configuration utility for weewx devices.

Options:
-h, --help            show this help message and exit
--debug               display diagnostic information while running
-y                    answer yes to every prompt
--info                display weather station configuration
--current             get the current weather conditions
--history=N           display N history records
--history-since=N     display history records since N minutes ago
--minmax              display historical min/max data
--get-date            display station date
--set-date=YEAR,MONTH,DAY
set station date
--sync-date           set station date using system clock
--get-location-local  display local location and timezone
--set-location-local=CITY|USR,LONG_DEG,LONG_MIN,E|W,LAT_DEG,LAT_MIN,N|S,TZ,DST
set local location and timezone
--get-location-alt    display alternate location and timezone
--set-location-alt=CITY|USR,LONG_DEG,LONG_MIN,E|W,LAT_DEG,LAT_MIN,N|S,TZ,DST
set alternate location and timezone
--get-altitude        display altitude
--set-altitude=ALT    set altitude (meters)
--get-alarms          display alarms
--set-alarms=WEEKDAY,SINGLE,PRE_ALARM,SNOOZE,MAXTEMP,MINTEMP,RAIN,WIND,GUST
set alarm state
--get-interval        display archive interval
--set-interval=INTERVAL
set archive interval (minutes)
--format=FORMAT       formats include: table, dict

Be sure to stop weewx first before using. Mutating actions will request
confirmation before proceeding.

```

### `--info` {id=te923_info}

Use `--info` to display the station
configuration:

    weectl device --info

This will result in something like:

```
Querying the station for the configuration...
altitude: 16
bat_1: True
bat_2: True
bat_3: True
bat_4: True
bat_5: True
bat_rain: True
bat_uv: False
bat_wind: True
latitude: 43.35
longitude: -72.0
version_bar: 23
version_rcc: 16
version_sys: 41
version_uv: 20
version_wind: 38
```

### `--current` {id=te923_current}

Use `--current` to display the current status of each sensor:

    weectl device --current

This will result in something like:

```
Querying the station for current weather data...
dateTime: 1454615168
forecast: 5
h_1: 41
h_1_state: ok
h_2: 48
h_2_state: ok
h_3: None
h_3_state: no_link
h_4: None
h_4_state: no_link
h_5: None
h_5_state: no_link
h_in: 44
h_in_state: ok
rain: 2723
rain_state: ok
slp: 1012.4375
slp_state: ok
storm: 0
t_1: 13.9
t_1_state: ok
t_2: 21.5
t_2_state: ok
t_3: None
t_3_state: no_link
t_4: None
t_4_state: no_link
t_5: None
t_5_state: no_link
t_in: 22.85
t_in_state: ok
uv: None
uv_state: no_link
windchill: None
windchill_state: invalid
winddir: 12
winddir_state: invalid
windgust: None
windgust_state: invalid
windspeed: None
windspeed_state: invalid
```

###  `--set-interval` {id=te923_set_interval}

TE923 stations ship from the factory with an archive interval of 1
hour (3600 seconds). To change the station's interval to 5 minutes
(300 seconds), do the following:

    weectl device --set-interval=300

### `--history=N` {id=te923_history}

Use the `--history` action to display
records from the logger in tabular or dictionary format.

For example, to display the most recent 30 records in dictionary
format:

    weectl device --history=30 --format=dict

### `--clear-memory` {id=te923_clear_memory}

Use `--clear-memory` to erase all records from the logger memory.

## Station data {id=te923_data}

The following table shows which data are provided by the station
hardware and which are calculated by WeeWX.

<table class='station_data'>
<caption>TE923 station data</caption>
<tbody class='code'>
<tr class="first_row">
<td style='width:200px'>Database Field</td>
<td>Observation</td>
<td>Loop</td>
<td>Archive</td>
</tr>
<tr>
<td class='first_col'>barometer</td>
<td>barometer</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>pressure</td>
<td></td>
<td>S</td>
<td>S</td>
</tr>
<tr>
<td class='first_col'>altimeter</td>
<td></td>
<td>S</td>
<td>S</td>
</tr>
<tr>
<td class='first_col'>inTemp</td>
<td>t_in</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>inHumidity</td>
<td>h_in</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>outTemp</td>
<td>t_1</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>outHumidity</td>
<td>h_1</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>outTempBatteryStatus</td>
<td>bat_1</td>
<td>H</td>
<td></td>
</tr>
<tr>
<td class='first_col'>outLinkStatus</td>
<td>link_1</td>
<td>H</td>
<td></td>
</tr>
<tr>
<td class='first_col'>windSpeed</td>
<td>windspeed</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>windDir</td>
<td>winddir</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>windGust</td>
<td>windgust</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>windBatteryStatus</td>
<td>bat_wind</td>
<td>H</td>
<td></td>
</tr>
<tr>
<td class='first_col'>windLinkStatus</td>
<td>link_wind</td>
<td>H</td>
<td></td>
</tr>
<tr>
<td class='first_col'>rain</td>
<td>rain</td>
<td>D</td>
<td>D</td>
</tr>
<tr>
<td class='first_col'></td>
<td>rain_total</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>rainBatteryStatus</td>
<td>bat_rain</td>
<td>H</td>
<td></td>
</tr>
<tr>
<td class='first_col'>rainLinkStatus</td>
<td>link_rain</td>
<td>H</td>
<td></td>
</tr>
<tr>
<td class='first_col'>rainRate</td>
<td></td>
<td>S</td>
<td>S</td>
</tr>
<tr>
<td class='first_col'>dewpoint</td>
<td></td>
<td>S</td>
<td>S</td>
</tr>
<tr>
<td class='first_col'>windchill</td>
<td>windchill</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>heatindex</td>
<td></td>
<td>S</td>
<td>S</td>
</tr>
<tr>
<td class='first_col'>UV<sup>1</sup></td>
<td>uv</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>uvBatteryStatus</td>
<td>bat_uv</td>
<td>H</td>
<td></td>
</tr>
<tr>
<td class='first_col'>uvLinkStatus</td>
<td>link_uv</td>
<td>H</td>
<td></td>
</tr>
<tr>
<td class='first_col'>extraTemp1</td>
<td>t_2</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>extraHumid1</td>
<td>h_2</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>extraBatteryStatus1</td>
<td>bat_2</td>
<td>H</td>
<td></td>
</tr>
<tr>
<td class='first_col'>extraLinkStatus1</td>
<td>link_2</td>
<td>H</td>
<td></td>
</tr>
<tr>
<td class='first_col'>extraTemp2</td>
<td>t_3</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>extraHumid2</td>
<td>h_3</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>extraBatteryStatus2</td>
<td>bat_3</td>
<td>H</td>
<td></td>
</tr>
<tr>
<td class='first_col'>extraLinkStatus2</td>
<td>link_3</td>
<td>H</td>
<td></td>
</tr>
<tr>
<td class='first_col'>extraTemp3</td>
<td>t_4</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>extraHumid3</td>
<td>h_4</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>extraBatteryStatus3</td>
<td>bat_4</td>
<td>H</td>
<td></td>
</tr>
<tr>
<td class='first_col'>extraLinkStatus3</td>
<td>link_4</td>
<td>H</td>
<td></td>
</tr>
<tr>
<td class='first_col'>extraTemp4</td>
<td>t_5</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>extraHumid4</td>
<td>h_5</td>
<td>H</td>
<td>H</td>
</tr>
<tr>
<td class='first_col'>extraBatteryStatus4</td>
<td>bat_5</td>
<td>H</td>
<td></td>
</tr>
<tr>
<td class='first_col'>extraLinkStatus4</td>
<td>link_5</td>
<td>H</td>
<td></td>
</tr>
</tbody>
</table>

<p class='station_data_key'>
Some stations support up to 5 remote temperature/humidity sensors.
</p>

<p class='station_data_key'>
<sup>1</sup> The <span class='code'>UV</span> data are available
only with the optional solar radiation sensor.
</p>

<p class='station_data_key'>
<b>H</b> indicates data provided by <b>H</b>ardware<br/>
<b>D</b> indicates data calculated by the <b>D</b>river<br/>
<b>S</b> indicates data calculated by the StdWXCalculate <b>S</b>ervice<br/>
</p>
