# WMR300 {id=wmr300_notes}


A single WMR300 console supports 1 wind, 1 rain, 1 UV, and up to 8 temperature/humidity sensors.

The WMR300 sensors send at different rates:

<table class='station_data'>
    <caption>WMR300 transmission periods</caption>
    <tbody>
        <tr class="first_row"><td>sensor</td><td>period</td></tr>
        <tr><td>Wind</td><td>2.5 to 3 seconds</td></tr>
        <tr><td>T/H</td><td>10 to 12 seconds</td></tr>
        <tr><td>Rain</td><td>20 to 24 seconds</td></tr>
    </tbody>
</table>

The console contains the pressure sensor.  The console reports pressure every 15 minutes.

The station emits partial packets, which may confuse some online services.

The rain counter has a limit of 400 inches (10160 mm).  The counter does not wrap around; it must
be reset when it hits the limit, otherwise additional rain data will not be recorded.

The logger stores about 50,000 records.  When the logger fills up, it stops recording data.

When WeeWX starts up it will attempt to download all records from the console since the last record
in the archive database. This can take as much as couple of hours, depending on the number of
records in the logger and the speed of the computer and disk.

## Configuring with `weectl device` {id=wrm300_configuration}

The WMR300 stations cannot be configured with the utility
[`weectl device`](../utilities/weectl-device.md).

## Station data {id=wmr300_data}

The following table shows which data are provided by the station hardware and which are calculated
by WeeWX.

<table class='station_data'>
    <caption>WMR300 station data</caption>
    <tbody class='code'>
    <tr class="first_row">
        <td style='width:200px'>Database Field</td>
        <td>Observation</td>
        <td>Loop</td>
        <td>Archive</td>
    </tr>
    <tr>
        <td class='first_col'>barometer</td>
        <td>barometer</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>pressure</td>
        <td>pressure</td>
        <td>H</td>
        <td>S</td>
    </tr>
    <tr>
        <td class='first_col'>altimeter</td>
        <td></td>
        <td>S</td>
        <td>S</td>
    </tr>
    <tr>
        <td class='first_col'>inTemp</td>
        <td>temperature_0</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>inHumidity</td>
        <td>humidity_0</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>windSpeed</td>
        <td>wind_avg</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>windDir</td>
        <td>wind_dir</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>windGust</td>
        <td>wind_gust</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>windGustDir</td>
        <td>wind_gust_dir</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>rain</td>
        <td>rain</td>
        <td>D</td>
        <td>D</td>
    </tr>
    <tr>
        <td class='first_col'></td>
        <td>rain_total</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>rainRate</td>
        <td>rain_rate</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>outTemp</td>
        <td>temperature_1</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>outHumidity</td>
        <td>humidity_1</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>dewpoint</td>
        <td>dewpoint_1</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>heatindex</td>
        <td>heatindex_1</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>windchill</td>
        <td>windchill</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraTemp1</td>
        <td>temperature_2</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraHumid1</td>
        <td>humidity_2</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraDewpoint1</td>
        <td>dewpoint_2</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraHeatindex1</td>
        <td>heatindex_2</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraTemp2</td>
        <td>temperature_3</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraHumid2</td>
        <td>humidity_3</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraDewpoint2</td>
        <td>dewpoint_3</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraHeatindex2</td>
        <td>heatindex_3</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraTemp3</td>
        <td>temperature_4</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraHumid3</td>
        <td>humidity_4</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraDewpoint3</td>
        <td>dewpoint_4</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraHeatindex3</td>
        <td>heatindex_4</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraTemp4</td>
        <td>temperature_5</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraHumid4</td>
        <td>humidity_5</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraDewpoint4</td>
        <td>dewpoint_5</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraHeatindex4</td>
        <td>heatindex_5</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraTemp5</td>
        <td>temperature_6</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraHumid5</td>
        <td>humidity_6</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraDewpoint5</td>
        <td>dewpoint_6</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraHeatindex5</td>
        <td>heatindex_6</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraTemp6</td>
        <td>temperature_7</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraHumid6</td>
        <td>humidity_7</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraDewpoint6</td>
        <td>dewpoint_7</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraHeatindex6</td>
        <td>heatindex_7</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraTemp7</td>
        <td>temperature_8</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraHumid7</td>
        <td>humidity_8</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraDewpoint7</td>
        <td>dewpoint_8</td>
        <td>H</td>
        <td>H</td>
    </tr>
    <tr>
        <td class='first_col'>extraHeatindex7</td>
        <td>heatindex_8</td>
        <td>H</td>
        <td>H</td>
    </tr>
    </tbody>
</table>
<p class='station_data_key'>
    Each packet contains a subset of all possible readings.
</p>

<p class='station_data_key'>
    <b>H</b> indicates data provided by <b>H</b>ardware<br/>
    <b>D</b> indicates data calculated by the <b>D</b>river<br/>
    <b>S</b> indicates data calculated by the StdWXCalculate <b>S</b>ervice<br/>
</p>

